@@ -15,6 +15,7 @@ from win32con import IDC_WAIT, MOUSEEVENTF_MOVE, MOUSEEVENTF_ABSOLUTE, MOUSEEVEN
 	WHEEL_DELTA
 from .core import type_separator, path_separator, get_entry, get_entry_list, find_element, get_sorted_region, \
 	get_wrapper_path, is_int
+from functools import partial, update_wrapper
 
 
 UI_Coordinates = NewType('UI_Coordinates', (float, float))
@@ -24,7 +25,7 @@ UI_Selector = Union[UI_Path, PYWINAUTO_Wrapper, UI_Coordinates]
 
 
 class PywinautoRecorderException(Exception):
-	"""Base class for other exceptions"""
+	"""Base class for other exceptions."""
 	pass
 
 
@@ -33,31 +34,39 @@ class FailedSearch(PywinautoRecorderException):
 	pass
 
 
-__all__ = ['PlayerSettings', 'MoveMode', 'load_dictionary', 'shortcut', 'full_definition', 'UIPath', 'Window', 'Region',
-           'find', 'move', 'click', 'left_click', 'right_click', 'double_left_click', 'triple_left_click',
-           'drag_and_drop', 'middle_drag_and_drop', 'right_drag_and_drop', 'menu_click', 'mouse_wheel', 'send_keys',
-           'set_combobox', 'set_text', 'exists', 'select_file']
+__all__ = ['PlayerSettings', 'MoveMode', 'ButtonLocation', 'load_dictionary', 'shortcut', 'full_definition', 'UIPath',
+           'Window', 'Region', 'find', 'find_all', 'move', 'click', 'left_click', 'right_click', 'double_left_click',
+           'triple_left_click', 'drag_and_drop', 'middle_drag_and_drop', 'right_drag_and_drop', 'menu_click',
+           'mouse_wheel', 'send_keys', 'set_combobox', 'set_text', 'exists', 'select_file']
 
 
 # TODO special_char_array in core for recorder.py and player.py (check when to call escape & unescape)
 def unescape_special_char(string):
 	for r in (("\\\\", "\\"), ("\\t", "\t"), ("\\n", "\n"), ("\\r", "\r"), ("\\v", "\v"), ("\\f", "\f"), ('\\"', '"')):
-		#for r in (("\\", "\\\\"), ("\t", "\\t"), ("\n", "\\n"), ("\r", "\\r"), ("\v", "\\v"), ("\f", "\\f"), ('"', '\\"')):
 		string = string.replace(*r)
 	return string
 
 
 class PlayerSettings:
+	"""The player settings class contains the mouse move duration and timeout."""
 	mouse_move_duration = 0.5
 	timeout = 10
 
 
 class MoveMode(Enum):
+	"""The MoveMode class is an enumeration of the different ways that the mouse can move"""
 	linear = 0
 	y_first = 1
 	x_first = 2
 
 
+class ButtonLocation(Enum):
+	"""The ButtonLocation class is an enumeration of the different locations of the mouse buttons"""
+	left = 0
+	middle = 1
+	right = 2
+
+
 _dictionary = {}
 unique_element_old = None
 element_path_old = ''
@@ -134,8 +143,56 @@ def wait_is_ready_try1(wrapper, timeout=120):
 			raise TimeoutError("Time out! ", msg)
 
 
-# > The class is used to keep track of the current path in the UI tree
 class UIPath(object):
+	"""
+	UIPath is a context manager used to keep track of the current path in the UI tree.
+	
+	.. code-block:: python
+		:caption: Example of code not using a 'UIPath' object::
+		:emphasize-lines: 3,4
+		
+		from pywinauto_recorder.player import click
+		
+		click("Calculator||Window->*->Number pad||Group->One||Button")
+		click("Calculator||Window->*->Number pad||Group->Two||Button")
+		
+	The code above clicks on two buttons. On each line that corresponds to a click operation, the whole path is repeated.
+	A UIPath object will allow to factorize a common path where several operations will be performed.
+	
+	The following code does the same as the previous example:
+	
+	.. code-block:: python
+		:caption: Example of code using a 'UIPath' object::
+		:emphasize-lines: 3,3
+		
+		from pywinauto_recorder.player import UIPath, click
+		
+		with UIPath("Calculator||Window"):
+			click("*->Number pad||Group->One||Button")
+			click("*->Number pad||Group->Two||Button")
+	
+	UIPath objects can be nested.
+	
+	The following code does the same as the previous example:
+	
+	.. code-block:: python
+		:caption: Example of code using nested 'UIPath' objects::
+		:emphasize-lines: 3,4
+		
+		from pywinauto_recorder.player import UIPath, click
+		
+		with UIPath("Calculator||Window"):
+			with UIPath("*->Number pad||Group"):
+				click("One||Button")
+				click("Two||Button")
+
+	Methods:
+	
+	Methods
+	-------
+	get_full_path(element_path: Optional[UI_Path] = None) -> UI_Path
+		Returns the full path of the element.
+	"""
 	_path_list = []
 	_regex_list = []
 	
@@ -148,10 +205,12 @@ class UIPath(object):
 		:type element_path: Optional[UI_Path]
 		:return: The full path of the element.
 		"""
-		if element_path is None:
+		if element_path is None or element_path == "":
 			return path_separator.join(UIPath._path_list)
-		else:
+		elif UIPath._path_list:
 			return path_separator.join(UIPath._path_list) + path_separator + element_path
+		else:
+			return element_path
 	
 	def __init__(self, relative_path=None, regex_title=False):
 		self.relative_path = relative_path
@@ -178,11 +237,22 @@ def find(
 		regex: bool=False,
 		timeout: Optional[float] = None) -> PYWINAUTO_Wrapper:
 	"""
-	Finds an element
+	Finds the element matching element_path.
 
+	.. code-block:: python
+		:caption: Example of code using the 'find' function::
+		:emphasize-lines: 3,3
+		
+		from pywinauto_recorder.player import UIPath, find
+		with UIPath("RegEx: .* Google Chrome$||Pane"):
+			find().set_focus()  # Set focus to the Google Chrome window.
+	
+	The code above will set focus to the Google Chrome window. The 'find' function is used to find the window.
+	It will work only if the window is not minimized.
+	
 	:param element_path: element path
 	:param timeout: period of time in seconds that will be allowed to find the element
-	:return: Pywinauto wrapper of clicked element
+	:return: Pywinauto wrapper of found element
 	"""
 	if regex:
 		deprecated_msg = """
@@ -203,7 +273,10 @@ def find(
 	if timeout is None:
 		timeout = PlayerSettings.timeout
 	
-	full_element_path = UIPath.get_full_path(element_path)
+	if element_path is None or isinstance(element_path, str):
+		full_element_path = UIPath.get_full_path(element_path)
+	else:
+		full_element_path = get_wrapper_path(element_path)
 	entry_list = get_entry_list(full_element_path)
 	_, _, y_x, _ = get_entry(entry_list[-1])
 	unique_element = None
@@ -256,6 +329,101 @@ def find(
 	return unique_element
 
 
+def find_all(
+		element_path: Optional[UI_Selector] = None,
+		timeout: Optional[float] = None) -> PYWINAUTO_Wrapper:
+	"""
+	Finds all elements matching element_path.
+
+	.. code-block:: python
+		:caption: Example of code using the 'find_all' function::
+		:emphasize-lines: 4,4
+		
+		from pywinauto_recorder.player import UIPath, find, find_all
+		with UIPath("RegEx: .* Google Chrome$||Pane"):
+			find().set_focus()
+			wrapper_tab_list = find_all("*->RegEx: .*||TabItem") # Find all tabs.
+			for wrapper_tab in wrapper_tab_list:
+				wrapper_tab.click_input()
+				wrapper_url = find("*->Address and search bar||Edit")
+				print(wrapper_url.get_value())
+		
+	The code above will click on all tabs of Google Chrome and print the URL of each tab.
+	It will work only if the Google Chrome window is not minimized.
+	The 'find_all' function is used to find all tabs.
+	
+	
+	:param element_path: element path
+	:param timeout: period of time in seconds that will be allowed to find the element
+	:return: Pywinauto wrapper list of found elements
+	"""
+	if timeout is None:
+		timeout = PlayerSettings.timeout
+	
+	if element_path is None or type(element_path) is str:
+		full_element_path = UIPath.get_full_path(element_path)
+	else:
+		full_element_path = get_wrapper_path(element_path)
+	entry_list = get_entry_list(full_element_path)
+	_, _, y_x, _ = get_entry(entry_list[-1])
+	if y_x:
+		return find(element_path, timeout=timeout)
+	unique_element = None
+	elements = None
+	t0 = time.time()
+	while (time.time() - t0) < timeout:
+		try:
+			unique_element, elements = find_element(entry_list)
+			if unique_element or elements:
+				break
+			if not unique_element and not elements:
+				time.sleep(2.0)
+		except Exception:
+			pass
+		if (time.time() - t0) > timeout:
+			msg = "No element found with the UIPath '" + full_element_path + "' after " + str(timeout) + " s of searching."
+			raise FailedSearch(msg)
+		time.sleep(0.1)
+
+	if unique_element:
+		return [unique_element]
+	else:
+		return elements
+
+
+def __move(x, y, xd, yd, duration=1, refresh_rate=25):
+	"""
+	It moves the mouse from (x, y) to (xd, yd) in a straight line, with a duration of `duration` seconds.
+	
+	:param x: The x-coordinate of the mouse cursor before the move
+	:param y: The y-coordinate of the mouse cursor before the move
+	:param xd: The x-coordinate of the mouse cursor after the move
+	:param yd: The y-coordinate of the mouse cursor after the move
+	:param duration: The time (in seconds) it takes to move the mouse from (x, y) to (xd, yd)
+	:param refresh_rate: 25 Hz is the default refresh rate of the mouse move
+	"""
+	x_max = win32api_GetSystemMetrics(0) - 1
+	y_max = win32api_GetSystemMetrics(1) - 1
+	if duration > 0:
+		samples = duration * refresh_rate
+		dt = 1 / refresh_rate
+		step_x = (xd - x) / samples
+		step_y = (yd - y) / samples
+		t0 = time.time()
+		for i in range(int(samples)):
+			x, y = x+step_x, y+step_y
+			t1 = time.time()
+			if t1-t0 > i*dt:
+				continue
+			time.sleep(dt)
+			nx = int(x * 65535 / x_max)
+			ny = int(y * 65535 / y_max)
+			win32api_mouse_event(MOUSEEVENTF_MOVE | MOUSEEVENTF_ABSOLUTE, nx, ny)
+	nx = round(xd * 65535 / x_max)
+	ny = round(yd * 65535 / y_max)
+	win32api_mouse_event(MOUSEEVENTF_MOVE | MOUSEEVENTF_ABSOLUTE, nx, ny)
+
+
 def move(
 		element_path: UI_Selector,
 		duration: Optional[float] = None,
@@ -265,7 +433,8 @@ def move(
 	Moves on element
 	
 	:param element_path: element path
-	:param duration: duration in seconds of the mouse move (if duration is -1 the mouse cursor doesn't move)
+	:param duration: duration in seconds of the mouse move (it doesn't take into account the time it takes to find),
+		if duration is -1 the mouse cursor doesn't move.
 	:param mode: move mouse mode
 	:param timeout: period of time in seconds that will be allowed to find the element
 	:return: Pywinauto wrapper of clicked element
@@ -323,38 +492,15 @@ def move(
 	else:
 		(xd, yd) = element_path
 		unique_element = None
-	x_max = win32api_GetSystemMetrics(0) - 1
-	y_max = win32api_GetSystemMetrics(1) - 1
-	if (x, y) != (xd, yd) and duration > 0:
-		dt = 0.01
-		samples = duration/dt
-		step_x = (xd-x)/samples
-		step_y = (yd-y)/samples
-		if mode == MoveMode.x_first:
-			for _ in range(int(samples)):
-				x = x+step_x
-				time.sleep(0.01)
-				nx = int(x * 65535 / x_max)
-				ny = int(y * 65535 / y_max)
-				win32api_mouse_event(MOUSEEVENTF_MOVE | MOUSEEVENTF_ABSOLUTE, nx, ny)
-			step_x = 0
-		if mode == MoveMode.y_first:
-			for _ in range(int(samples)):
-				y = y+step_y
-				time.sleep(0.01)
-				nx = int(x * 65535 / x_max)
-				ny = int(y * 65535 / y_max)
-				win32api_mouse_event(MOUSEEVENTF_MOVE | MOUSEEVENTF_ABSOLUTE, nx, ny)
-			step_y = 0
-		for _ in range(int(samples)):
-			x, y = x+step_x, y+step_y
-			time.sleep(0.01)
-			nx = int(x * 65535 / x_max)
-			ny = int(y * 65535 / y_max)
-			win32api_mouse_event(MOUSEEVENTF_MOVE | MOUSEEVENTF_ABSOLUTE, nx, ny)
-	nx = round(xd * 65535 / x_max)
-	ny = round(yd * 65535 / y_max)
-	win32api_mouse_event(MOUSEEVENTF_MOVE | MOUSEEVENTF_ABSOLUTE, nx, ny)
+	if (x, y) != (xd, yd):
+		if mode == MoveMode.linear:
+			__move(x, y, xd, yd, duration)
+		elif mode == MoveMode.x_first:
+			__move(x, y, xd, y, duration/2)
+			__move(xd, y, xd, yd, duration/2)
+		elif mode == MoveMode.y_first:
+			__move(x, y, x, yd, duration/2)
+			__move(x, yd, xd, yd, duration/2)
 	if unique_element is None:
 		return None
 	unique_element_old = unique_element
@@ -366,19 +512,29 @@ def move(
 def click(
 		element_path: Optional[UI_Selector] = None,
 		duration: Optional[float] = None,
-		mode: Enum = MoveMode.linear,
-		button: str = 'left',
+		mode: MoveMode = MoveMode.linear,
+		button: ButtonLocation = ButtonLocation.left,
+		click_count: int = 1,
 		timeout: float = None,
 		wait_ready: bool = True) -> PYWINAUTO_Wrapper:
 	"""
-	Clicks on element
+	Clicks on found element.
+	
+	.. code-block:: python
+		:caption: Example of code using the 'click' function::
+		:emphasize-lines: 3,3
+		
+		from pywinauto_recorder.player import click, MoveMode
+		
+		click("Calculator||Window->*->One||Button", mode=MoveMode.x_first, duration=4)
 	
 	:param element_path: element path
-	:param duration: duration in seconds of the mouse move
+	:param duration: duration in seconds of the mouse move (it doesn't take into account the time it takes to find)
 		(if duration is -1 the mouse cursor doesn't move, it just sends WM_CLICK window message,
 		useful for minimized or non-active window).
-	:param mode: move mouse mode
-	:param button: mouse button: 'left','double_left', 'triple_left', 'right'
+	:param mode: move mouse mode: MoveMode.linear, MoveMode.x_first, MoveMode.y_first
+	:param button: mouse button:  ButtonLocation.left, ButtonLocation.middle, ButtonLocation.right
+	:param click_count: number of clicks
 	:param timeout: period of time in seconds that will be allowed to find the element
 	:param wait_ready: if True waits until the element is ready
 	:return: Pywinauto wrapper of clicked element
@@ -404,105 +560,41 @@ def click(
 				wait_is_ready_try1(wrapper, timeout=timeout)
 			else:
 				wrapper = None
-	if button == 'left' or button == 'double_left' or button == 'triple_left':
-		win32api_mouse_event(MOUSEEVENTF_LEFTDOWN, 0, 0)
+	if button == ButtonLocation.left:
+		event_down = MOUSEEVENTF_LEFTDOWN
+		event_up = MOUSEEVENTF_LEFTUP
+	elif button == ButtonLocation.middle:
+		event_down = MOUSEEVENTF_MIDDLEDOWN
+		event_up = MOUSEEVENTF_MIDDLEUP
+	elif button == ButtonLocation.right:
+		event_down = MOUSEEVENTF_RIGHTDOWN
+		event_up = MOUSEEVENTF_RIGHTUP
+	for _ in range(click_count):
+		win32api_mouse_event(event_down, 0, 0)
 		time.sleep(.01)
-		win32api_mouse_event(MOUSEEVENTF_LEFTUP, 0, 0)
+		win32api_mouse_event(event_up, 0, 0)
 		time.sleep(.1)
-	if button == 'double_left' or button == 'triple_left':
-		win32api_mouse_event(MOUSEEVENTF_LEFTDOWN, 0, 0)
-		time.sleep(.01)
-		win32api_mouse_event(MOUSEEVENTF_LEFTUP, 0, 0)
-		time.sleep(.1)
-	if button == 'triple_left':
-		win32api_mouse_event(MOUSEEVENTF_LEFTDOWN, 0, 0)
-		time.sleep(.01)
-		win32api_mouse_event(MOUSEEVENTF_LEFTUP, 0, 0)
-	if button == 'right':
-		win32api_mouse_event(MOUSEEVENTF_RIGHTDOWN, 0, 0)
-		time.sleep(.01)
-		win32api_mouse_event(MOUSEEVENTF_RIGHTUP, 0, 0)
-		time.sleep(.01)
 	if element_path:
 		return wrapper
 	else:
 		return None
 
 
-def left_click(
-		element_path: UI_Selector,
-		duration: Optional[float] = None,
-		mode: Enum = MoveMode.linear,
-		timeout: Optional[float] = None,
-		wait_ready: bool = True) -> PYWINAUTO_Wrapper:
-	"""
-	Left clicks on element
-	
-	:param element_path: element path
-	:param duration: duration in seconds of the mouse move (if duration is -1 the mouse cursor doesn't move)
-	:param mode: move mouse mode
-	:param timeout: period of time in seconds that will be allowed to find the element
-	:param wait_ready: if True waits until the element is ready
-	:return: Pywinauto wrapper of clicked element
-	"""
-	return click(element_path, duration=duration, mode=mode, button='left', timeout=timeout, wait_ready=wait_ready)
+def wrapped_partial(func, *args, **kwargs):
+	partial_func = partial(func, *args, **kwargs)
+	update_wrapper(partial_func, func)
+	partial_func.__doc__ = "This function is a partial function derived from the '" + func.__name__ + "' general function."
+	partial_func.__doc__ += "\nThe parameters of the function are set with the following values:"
+	for key in kwargs.keys():
+		partial_func.__doc__ += "\n    - " + str(key) + "=" + str(kwargs[key])
+	partial_func.__doc__ += "\n\n" + func.__doc__
+	return partial_func
 
 
-def right_click(
-		element_path: UI_Selector,
-		duration: Optional[float] = None,
-		mode: Enum = MoveMode.linear,
-		timeout: Optional[float] = None,
-		wait_ready: bool = True) -> PYWINAUTO_Wrapper:
-	"""
-	Right clicks on element
-	
-	:param element_path: element path
-	:param duration: duration in seconds of the mouse move (if duration is -1 the mouse cursor doesn't move)
-	:param mode: move mouse mode
-	:param timeout: period of time in seconds that will be allowed to find the element
-	:param wait_ready: if True waits until the element is ready
-	:return: Pywinauto wrapper of clicked element
-	"""
-	return click(element_path, duration=duration, mode=mode, button='right', timeout=timeout, wait_ready=wait_ready)
-
-
-def double_left_click(
-		element_path: UI_Selector,
-		duration: Optional[float] = None,
-		mode: Enum = MoveMode.linear,
-		timeout: Optional[float] = None,
-		wait_ready: bool = True) -> PYWINAUTO_Wrapper:
-	"""
-	Double left clicks on element
-	
-	:param element_path: element path
-	:param duration: duration in seconds of the mouse move (if duration is -1 the mouse cursor doesn't move)
-	:param mode: move mouse mode
-	:param timeout: period of time in seconds that will be allowed to find the element
-	:param wait_ready: if True waits until the element is ready
-	:return: Pywinauto wrapper of clicked element
-	"""
-	return click(element_path, duration=duration, mode=mode, button='double_left', timeout=timeout, wait_ready=wait_ready)
-
-
-def triple_left_click(
-		element_path: UI_Selector,
-		duration: Optional[float] = None,
-		mode: Enum = MoveMode.linear,
-		timeout: Optional[float] = None,
-		wait_ready: bool = True) -> PYWINAUTO_Wrapper:
-	"""
-	Triple left clicks on element
-	
-	:param element_path: element path
-	:param duration: duration in seconds of the mouse move (if duration is -1 the mouse cursor doesn't move)
-	:param mode: move mouse mode
-	:param timeout: period of time in seconds that will be allowed to find the element
-	:param wait_ready: if True waits until the element is ready
-	:return: Pywinauto wrapper of clicked element
-	"""
-	return click(element_path, duration=duration, mode=mode, button='triple_left', timeout=timeout, wait_ready=wait_ready)
+left_click = wrapped_partial(click, button=ButtonLocation.left)
+right_click = wrapped_partial(click, button=ButtonLocation.right)
+double_left_click = wrapped_partial(click, button=ButtonLocation.left, click_count=2)
+triple_left_click = wrapped_partial(click, button=ButtonLocation.left, click_count=3)
 
 
 def drag_and_drop(
@@ -510,68 +602,40 @@ def drag_and_drop(
 		element_path2: UI_Selector,
 		duration: Optional[float] = None,
 		mode: Enum = MoveMode.linear,
+		button: ButtonLocation = ButtonLocation.left,
 		timeout: Optional[float] = None) -> PYWINAUTO_Wrapper:
 	"""
 	Drags and drop with left button pressed from element_path1 to element_path2.
 	
 	:param element_path1: element path
 	:param element_path2: element path
-	:param duration: duration in seconds of the mouse move (if duration is -1 the mouse cursor doesn't move)
-	:param mode: move mouse mode
+	:param duration: duration in seconds of the mouse move (it doesn't take into account the time it takes to find)
+		(if duration is -1 the mouse cursor doesn't move, it just sends WM_CLICK window message,
+		useful for minimized or non-active window).
+	:param mode: move mouse mode: MoveMode.linear, MoveMode.x_first, MoveMode.y_first
+	:param button: mouse button:  ButtonLocation.left, ButtonLocation.middle, ButtonLocation.right
 	:param timeout: period of time in seconds that will be allowed to find the element
 	:return: Pywinauto wrapper with element_path2
 	"""
 	move(element_path1, duration=duration, mode=mode, timeout=timeout)
-	win32api_mouse_event(MOUSEEVENTF_LEFTDOWN, 0, 0)
+	if button == ButtonLocation.left:
+		event_down = MOUSEEVENTF_LEFTDOWN
+		event_up = MOUSEEVENTF_LEFTUP
+	elif button == ButtonLocation.middle:
+		event_down = MOUSEEVENTF_MIDDLEDOWN
+		event_up = MOUSEEVENTF_MIDDLEUP
+	elif button == ButtonLocation.right:
+		event_down = MOUSEEVENTF_RIGHTDOWN
+		event_up = MOUSEEVENTF_RIGHTUP
+	win32api_mouse_event(event_down, 0, 0)
 	unique_element = move(element_path2, duration=duration, timeout=timeout)
-	win32api_mouse_event(MOUSEEVENTF_LEFTUP, 0, 0)
+	win32api_mouse_event(event_up, 0, 0)
 	return unique_element
 
 
-def middle_drag_and_drop(
-		element_path1: UI_Selector,
-		element_path2: UI_Selector,
-		duration: Optional[float] = None,
-		mode: Enum = MoveMode.linear,
-		timeout: Optional[float] = None) -> PYWINAUTO_Wrapper:
-	"""
-	Drags and drop with middle button pressed from element_path1 to element_path2.
-	
-	:param element_path1: element path
-	:param element_path2: element path
-	:param duration: duration in seconds of the mouse move (if duration is -1 the mouse cursor doesn't move)
-	:param mode: move mouse mode
-	:param timeout: period of time in seconds that will be allowed to find the element
-	:return: Pywinauto wrapper with element_path2
-	"""
-	move(element_path1, duration=duration, mode=mode, timeout=timeout)
-	win32api_mouse_event(MOUSEEVENTF_MIDDLEDOWN, 0, 0)
-	unique_element = move(element_path2, duration=duration, mode=mode, timeout=timeout)
-	win32api_mouse_event(MOUSEEVENTF_MIDDLEUP, 0, 0)
-	return unique_element
-
-
-def right_drag_and_drop(
-		element_path1: UI_Selector,
-		element_path2: UI_Selector,
-		duration: Optional[float] = None,
-		mode: Enum = MoveMode.linear,
-		timeout: Optional[float] = None) -> PYWINAUTO_Wrapper:
-	"""
-	Drags and drop with right button pressed from element_path1 to element_path2.
-	
-	:param element_path1: element path
-	:param element_path2: element path
-	:param duration: duration in seconds of the mouse move (if duration is -1 the mouse cursor doesn't move)
-	:param mode: move mouse mode
-	:param timeout: period of time in seconds that will be allowed to find the element
-	:return: Pywinauto wrapper with element_path2
-	"""
-	move(element_path1, duration=duration, mode=mode, timeout=timeout)
-	win32api_mouse_event(MOUSEEVENTF_RIGHTDOWN, 0, 0)
-	unique_element = move(element_path2, duration=duration, mode=mode, timeout=timeout)
-	win32api_mouse_event(MOUSEEVENTF_RIGHTUP, 0, 0)
-	return unique_element
+left_drag_and_drop = wrapped_partial(drag_and_drop, button=ButtonLocation.left)
+middle_drag_and_drop = wrapped_partial(drag_and_drop, button=ButtonLocation.middle)
+right_drag_and_drop = wrapped_partial(drag_and_drop, button=ButtonLocation.right)
 
 
 def menu_click(
@@ -586,8 +650,10 @@ def menu_click(
 	
 	:param element_path: element path
 	:param menu_path: menu path
-	:param duration: duration in seconds of the mouse move (if duration is -1 the mouse cursor doesn't move)
-	:param mode: move mouse mode
+	:param duration: duration in seconds of the mouse move (it doesn't take into account the time it takes to find)
+		(if duration is -1 the mouse cursor doesn't move, it just sends WM_CLICK window message,
+		useful for minimized or non-active window).
+	:param mode: move mouse mode: MoveMode.linear, MoveMode.x_first, MoveMode.y_first
 	:param menu_type: menu type ('QT', 'NPP')
 	:param timeout: period of time in seconds that will be allowed to find the element
 	:return: Pywinauto wrapper of the clicked item
@@ -685,8 +751,10 @@ def set_combobox(
 	
 	:param element_path: element path
 	:param value: value of the combobox
-	:param duration: duration in seconds of the mouse move (if duration is -1 the mouse cursor doesn't move)
-	:param mode: move mouse mode
+	:param duration: duration in seconds of the mouse move (it doesn't take into account the time it takes to find)
+		(if duration is -1 the mouse cursor doesn't move, it just sends WM_CLICK window message,
+		useful for minimized or non-active window).
+	:param mode: move mouse mode: MoveMode.linear, MoveMode.x_first, MoveMode.y_first
 	:param timeout: period of time in seconds that will be allowed to find the element
 	"""
 	left_click(element_path, duration=duration, mode=mode, timeout=timeout, wait_ready=wait_ready)
@@ -706,8 +774,10 @@ def set_text(
 	
 	:param element_path: element path
 	:param value: value of the combobox
-	:param duration: duration in seconds of the mouse move (if duration is -1 the mouse cursor doesn't move)
-	:param mode: move mouse mode
+	:param duration: duration in seconds of the mouse move (it doesn't take into account the time it takes to find)
+		(if duration is -1 the mouse cursor doesn't move, it just sends WM_CLICK window message,
+		useful for minimized or non-active window).
+	:param mode: move mouse mode: MoveMode.linear, MoveMode.x_first, MoveMode.y_first
 	:param timeout: period of time in seconds that will be allowed to find the element
 	:param pause: pause in seconds between each typed key
 	"""
@@ -732,7 +802,7 @@ def exists(
 	try:
 		wrapper = find(element_path, timeout=timeout)
 		return wrapper
-	except TimeoutError:
+	except FailedSearch:
 		return None
 
 
@@ -743,6 +813,16 @@ def select_file(
 	"""
 	Selects a file in an already opened file dialog.
 	
+	.. code-block:: python
+		:caption: Example of code using 'select_file'::
+		:emphasize-lines: 3,3
+		
+		from pywinauto_recorder.player import select_file
+		
+		select_file("Document - WordPad||Window->Open||Window", "Documents/file.txt")
+	
+	To make this code work, you must first launch 'WordPad' and click on 'File->Open'.
+
 	:param window_path: window path of the file dialog (e.g. "Untitled - Paint||Window->Save As||Window"
 	:param full_path: the full path of the file to select
 	:param force_slow_path_typing: if True it will type the path even if the current path of the dialog box is the same
@@ -754,14 +834,14 @@ def select_file(
 	folder = p.parent
 	filename = p.name
 	with UIPath(window_path):
-		wrapper = find()
-		wait_is_ready_try1(wrapper)
-		left_click(wrapper.descendants(title="All locations", control_type="SplitButton")[0])
-		if not force_slow_path_typing:
-			send_keys("{VK_CONTROL down}c{VK_CONTROL up}")
-		if force_slow_path_typing or pathlib.Path(pyperclip.paste()) != folder:
-			send_keys(str(folder))
-		send_keys("{ENTER}")
-		double_left_click(u"*->File name:||ComboBox->File name:||Edit")
+		find().set_focus()
+		click("*->All locations||SplitButton")
+	if not force_slow_path_typing:
+		send_keys("{VK_CONTROL down}c{VK_CONTROL up}")
+	if force_slow_path_typing or pathlib.Path(pyperclip.paste()) != folder:
+		send_keys(str(folder))
+	send_keys("{ENTER}")
+	with UIPath(window_path):
+		double_left_click("*->File name:||ComboBox->File name:||Edit")
 		send_keys(filename + "{ENTER}")
 
