@@ -28,6 +28,7 @@ MenuEvent = namedtuple('MenuEvent', ['path', 'menu_path', 'menu_type'])
 
 
 class IconSet:
+	""" It loads the icons from the Icons folder and stores them in the class."""
 	if "__compiled__" in globals():
 		path_icons = os.path.dirname(os.path.realpath(__file__)) + r'\..'
 	else:
@@ -119,7 +120,10 @@ def write_in_file(events, relative_coordinate_mode=False):
 				if common_path:
 					p = get_relative_path(common_path, p)
 				str_c = ['', '', 'double_', 'triple_']
-				script += str_c[e_i.click_count] + e_i.button + '_click(u"' + escape_special_char(p)
+				if e_i.count == 1 and e_i.button == 'left':
+					script += 'click(u"' + escape_special_char(p)
+				else:
+					script += str_c[e_i.click_count] + e_i.button + '_click(u"' + escape_special_char(p)
 				if relative_coordinate_mode and eval(dx) != 0 and eval(dy) != 0:
 					script += '%(' + dx + ',' + dy + ')'
 				script += '")\n'
@@ -898,6 +902,9 @@ class Recorder(Thread):
 	'''
 	
 	def run(self):
+		"""
+		The function is called in a loop, and it tries to find the unique element under the mouse cursor.
+		"""
 		import comtypes.client
 		print("COMPTYPES CACHE FOLDER:", comtypes.client._code_cache._find_gen_dir())
 		
@@ -1097,37 +1104,81 @@ class Recorder(Thread):
 
 	@property
 	def process_menu_click_mode(self):
+		"""
+		If True, the process menu events are recorded else they are ignored.
+	
+		:return: The state of the process menu click mode.
+		"""
 		return self._process_menu_click_mode
 	
 	@process_menu_click_mode.setter
 	def process_menu_click_mode(self, value):
+		"""
+		It sets the state of the process menu click mode.
+		
+		:param value: If the value is True, the process menu events are recorded else they are ignored.
+		"""
 		self._process_menu_click_mode = value
 
 	@property
 	def relative_coordinate_mode(self):
+		"""
+		If True, the relative coordinates are recorded else they are ignored.
+
+		:return: The state of the relative coordinates mode.
+		"""
 		return self._relative_coordinate_mode
 	
 	@relative_coordinate_mode.setter
 	def relative_coordinate_mode(self, value):
+		"""
+		It sets the state of the relative coordinates mode.
+
+		:param value: If the value is True, the relative coordinates are recorded else they are ignored.
+		"""
 		self._relative_coordinate_mode = value
 
 	@property
 	def smart_mode(self):
+		"""
+		If True, the smart mode is activated.
+		:return: The state of the smart mode.
+		"""
 		return self._smart_mode
 	
 	@smart_mode.setter
 	def smart_mode(self, value):
+		"""
+		It sets the state of the smart mode.
+
+		:param value: If the value is True, the smart mode is activated else it is not activated.
+		"""
 		self._smart_mode = value
 
 	@property
 	def mode(self):
+		"""
+    It returns the mode of the recorder: "Record", "Play", "Info", "Stop", "Quit"
+			
+		:return: The mode of the recorder.
+		"""
 		return self._mode
 	
 	@mode.setter
 	def mode(self, value):
+		"""
+		It sets the mode of the recorder: "Record", "Play", "Info", "Stop", "Quit"
+		
+		:param value: The mode of the recorder.
+		"""
 		self._mode = value
 
 	def start_recording(self):
+		"""
+		Start recording:
+		It adds a mouse move event to the event list, displays the record icon to the main overlay,
+		clears and refreshes the main and info overlays, and then sets the mode to "Record".
+		"""
 		x, y = win32api.GetCursorPos()
 		self.event_list = [mouse.MoveEvent(x, y, time.time())]
 		overlay_add_mode_icon(self.main_overlay, IconSet.hicon_record, 10, 10)
@@ -1138,6 +1189,12 @@ class Recorder(Thread):
 		self.mode = "Record"
 
 	def stop_recording(self):
+		"""
+		Stop recording:
+		It cleans the event list, displays the stop icon to the main overlay,
+		clears and refreshes the main and info overlays, writes the Python script, and then sets the mode to "Stop".
+		:return: The name of the file that was created.
+		"""
 		if self.mode == "Record" and len(self.event_list) > 2:
 			events = list(self.event_list)
 			self.event_list = []
@@ -1157,9 +1214,16 @@ class Recorder(Thread):
 		return None
 
 	def get_last_element_event(self):
+		"""
+		It returns the last element of the event.
+		:return: The last element event.
+		"""
 		return self.last_element_event
 
 	def quit(self):
+		"""
+		The function clears the main and info overlays, sets the mode to 'Quit', and then joins the thread.
+		"""
 		self.info_overlay.clear_all()
 		self.main_overlay.clear_all()
 		self.main_overlay.refresh()
